<?php
/**
 * OEKOPOST HTTP-SOAP-Schnittstelle
 * PHP-Beispiel
 *
 * Erfordert PHP >= 5.0.1 mit SOAP-Erweiterung:
 *     htttp://www.php.net/soap
 */

// Anforderungen pruefen
if(!class_exists('SoapClient'))
	die('Die SoapClient-Klasse ist nicht verf&uuml;gbar. Die PHP-Version ist '
		. 'entweder zu alt oder die SOAP-Erweiterung ist nicht verf&uuml;gbar.');

// Login-Eingaben auslesen
$username 		= isset($_POST['username'])
					? $_POST['username']
					: '';
$password		= isset($_POST['password'])
					? $_POST['password']
					: '';

// Zufaelligen Salz-Wert erstellen
$salt			= substr(md5(uniqid()), 0, 8);

// Passwort-Hash generieren
$passwordHash	= md5(md5($password) . $salt);

// SOAP-Schnittstelle oeffnen
$oekopost 		= new SoapClient('https://www.oekopost.de/soap/?wsdl');
?>
<html>
	<head>
		<title>OEKOPOST HTTP-SOAP-Schnittstelle - PHP-Beispiel</title>
	</head>
	
	<body>
		
		<h1>OEKOPOST HTTP-SOAP-Schnittstelle</h1>
		<h2>PHP-Beispiel</h2>
		
		<p>
			Geben Sie Ihre Login-Daten in die &quot;Login&quot;-Box ein und w&auml;hlen Sie eine
			der nachfolgenden Aktionen.
		</p>
		
		<form action="example.php" method="post" enctype="multipart/form-data">
			<fieldset>
				<legend>Login</legend>
				
				<strong>Benutzername:</strong><br />
				<input type="text" name="username" value="<?php echo htmlentities($username); ?>" /><br /><br />
				
				<strong>Passwort:</strong><br />
				<input type="password" name="password" value="<?php echo htmlentities($password); ?>" />
			</fieldset>
			
			<!--
					Login pruefen
			-->
			<br /><br />
			<fieldset>
				<legend>Login pr&uuml;fen</legend>
				
				<input type="submit" name="doCheckLogin" value=" Login pr&uuml;fen " />
				
				<?php
				if(isset($_POST['doCheckLogin']))
				{
					// checkAccountLogin-Funktion der Schnittstelle aufrufen
					$result = $oekopost->checkAccountLogin($username, $passwordHash, $salt);
					
					?>
					<br /><br />
					<fieldset>
						<legend>Ergebnis</legend>
						<strong>Status:</strong> <?php echo($result); ?>
					</fieldset>
					<?php 
				}
				?>
			</fieldset>
			
			<!--
					Guthaben abfragen
			-->
			<br /><br />
			<fieldset>
				<legend>Guthaben abfragen</legend>
				
				<input type="submit" name="doGetBalance" value=" Guthaben abfragen " />
				
				<?php
				if(isset($_POST['doGetBalance']))
				{
					// getAccountBalance-Funktion der Schnittstelle aufrufen
					$result = $oekopost->getAccountBalance($username, $passwordHash, $salt);
					
					?>
					<br /><br />
					<fieldset>
						<legend>Ergebnis</legend>
						<strong>Status:</strong> <?php echo($result['status']); ?><br />
						<strong>Guthaben:</strong> <?php echo(number_format($result['balanceCents']/100, 2, ',', '.')); ?> &euro;
					</fieldset>
					<?php 
				}
				?>
			</fieldset>
			
			<!--
					Brief versenden
			-->
			<br /><br />
			<fieldset>
				<legend>Brief versenden</legend>
				
				<strong>PDF-Datei:</strong><br />
				<input type="file" name="letter_pdf" /><br /><br />
				
				<strong>Ziel-Land:</strong><br />
				<select name="letter_country">
					<option value="DE">Deutschland</option>
					<option value="_EUR">Europa</option>
					<option value="_WELT">Welt</option>
				</select><br /><br />
				
				<input type="radio" name="letter_envelope" value="C6" checked="checked" /> C6-Umschlag
				<input type="radio" name="letter_envelope" value="C5" /> C5-Umschlag<br /><br />
				
				<input type="checkbox" name="letter_color" checked="checked" /> <strong>Farb-Druck</strong><br />
				
				<input type="checkbox" name="letter_duplex" /> <strong>Duplex-Druck</strong><br /><br />
				
				<input type="submit" name="doSubmitLetter" value=" Brief versenden " />
				
				<?php
				if(isset($_POST['doSubmitLetter']))
				{
					if(isset($_FILES['letter_pdf']) && $_FILES['letter_pdf']['error'] == 0)
					{
						// PDF-Datei einlesen
						$data 		= file_get_contents($_FILES['letter_pdf']['tmp_name']);
						
						// MD5-hash der Daten berechnen
						$dataHash 	= md5($data);
						
						// submitPDFLetter-Funktion der Schnittstelle aufrufen
						$result = $oekopost->submitPDFLetter($username, $passwordHash, $salt,
															 $data, $dataHash,
															 time(), // Brief sofort senden
															 isset($_POST['letter_color']),
															 isset($_POST['letter_duplex']),
															 $_POST['letter_envelope'],
															 $_POST['letter_country']);
						
						// Ergebnis ausgeben
						?>
						<br /><br />
						<fieldset>
							<legend>Ergebnis</legend>
							
							<strong>Status:</strong> <?php echo($result['status']); ?><br />
							<strong>Auftrags-Kennung:</strong> <?php echo($result['jobID']); ?><br />
							<strong>Abgerechnet:</strong> <?php echo(number_format($result['chargedCents']/100, 2, ',', '.')); ?> &euro;
						</fieldset>
						<?php
					}
					else
					{
						?>
						<br /><br />
						<fieldset>
							<legend>Ergebnis</legend>
							
							<strong>Fehler:</strong> PDF-Upload fehlgeschlagen.
						</fieldset>
						<?php 
					}
				}
				?>
			</fieldset>
			
			<!--
					SMS versenden
			-->
			<br /><br />
			<fieldset>
				<legend>SMS versenden</legend>
				
				<strong>SMS-Typ:</strong><br />
				<select name="sms_type">
					<option value="0">SMS mit eigenem Absender</option>
					<option value="1">SMS ohne eigenem Absender</option>
				</select><br /><br />
				
				<strong>Absender:</strong><br />
				<input type="text" name="sms_from" /><br /><br />
				
				<strong>Empf&auml;nger:</strong><br />
				<input type="text" name="sms_to" /><br /><br />
				
				<strong>Text:</strong><br />
				<textarea name="sms_text"></textarea><br /><br />
				
				<input type="submit" name="doSubmitSMS" value=" SMS versenden " />
				
				<?php
				if(isset($_POST['doSubmitSMS']))
				{
					// submitSMS-Funktion der Schnittstelle aufrufen
					$result = $oekopost->submitSMS($username, $passwordHash, $salt,
												   $_POST['sms_from'],
												   $_POST['sms_to'],
												   $_POST['sms_text'],
												   time(), // SMS sofort versenden
												   (int)$_POST['sms_type']);
					
					// Ergebnis ausgeben
					?>
					<br /><br />
					<fieldset>
						<legend>Ergebnis</legend>
						
						<strong>Status:</strong> <?php echo($result['status']); ?><br />
						<strong>Auftrags-Kennung:</strong> <?php echo($result['jobID']); ?><br />
						<strong>Abgerechnet:</strong> <?php echo(number_format($result['chargedCents']/100, 2, ',', '.')); ?> &euro;
					</fieldset>
					<?php
				}
				?>
			</fieldset>
		</form>
		
	</body>
</html>
